@@ -260,6 +260,31 @@ static LinkedListInfo *AcquireMagicList(ExceptionInfo *exception)
 %    o exception: return any errors or warnings in this structure.
 %
 */
+
+static inline MagickBooleanType CompareMagic(const unsigned char *magic,
+  const size_t length,const MagicInfo *magic_info)
+{
+  const unsigned char
+    *q;
+
+  MagickOffsetType
+    remaining;
+
+  assert(magic_info->offset >= 0);
+  q=magic+magic_info->offset;
+  remaining=(MagickOffsetType) length-magic_info->offset;
+  if (magic_info->skip_spaces != MagickFalse)
+    while ((remaining > 0) && (isspace(*q) != 0))
+    {
+      q++;
+      remaining--;
+    }
+  if ((remaining >= magic_info->length) &&
+      (memcmp(q,magic_info->magic,magic_info->length) == 0))
+    return(MagickTrue);
+  return(MagickFalse);
+}
+
 static MagickBooleanType IsMagicCacheInstantiated()
 {
   if (magic_cache == (LinkedListInfo *) NULL)
@@ -280,9 +305,6 @@ MagickExport const MagicInfo *GetMagicInfo(const unsigned char *magic,
   const MagicInfo
     *p;
 
-  MagickOffsetType
-    offset;
-
   assert(exception != (ExceptionInfo *) NULL);
   if (IsMagicListInstantiated(exception) == MagickFalse)
     return((const MagicInfo *) NULL);
@@ -298,16 +320,7 @@ MagickExport const MagicInfo *GetMagicInfo(const unsigned char *magic,
       p=(const MagicInfo *) GetNextValueInLinkedList(magic_cache);
       while (p != (const MagicInfo *) NULL)
       {
-        const unsigned char
-          *q;
-
-        q=magic;
-        if (p->skip_spaces != MagickFalse)
-          while (isspace(*q) != 0) q++;
-        assert(p->offset >= 0);
-        offset=p->offset+(MagickOffsetType) p->length;
-        if ((offset <= (MagickOffsetType) length) &&
-            (memcmp(q+p->offset,p->magic,p->length) == 0))
+        if (CompareMagic(magic,length,p) != MagickFalse)
           break;
         p=(const MagicInfo *) GetNextValueInLinkedList(magic_cache);
       }
@@ -328,16 +341,7 @@ MagickExport const MagicInfo *GetMagicInfo(const unsigned char *magic,
     }
   while (p != (const MagicInfo *) NULL)
   {
-    const unsigned char
-      *q;
-
-    q=magic;
-    if (p->skip_spaces != MagickFalse)
-      while (isspace(*q) != 0) q++;
-    assert(p->offset >= 0);
-    offset=p->offset+(MagickOffsetType) p->length;
-    if ((offset <= (MagickOffsetType) length) &&
-        (memcmp(q+p->offset,p->magic,p->length) == 0))
+    if (CompareMagic(magic,length,p) != MagickFalse)
       break;
     p=(const MagicInfo *) GetNextValueInLinkedList(magic_list);
   }
